@@ -134,12 +134,7 @@
 #ifndef FIFTYONE_DEGREES_NO_THREADING
 #include "threading.h"
 #endif
-
-#ifdef __cplusplus
-#define EXTERNAL extern "C"
-#else
-#define EXTERNAL
-#endif
+#include "common.h"
 
  /** @cond FORWARD_DECLARATIONS */
 typedef struct fiftyone_degrees_pool_item_t fiftyoneDegreesPoolItem;
